@@ -19,7 +19,11 @@
 ### ExperimentList class
 ### ----------------------------------------------
 
-#' A container for multi-experiment data
+#' @name ExperimentList-class
+#'
+#' @docType class
+#'
+#' @title ExperimentList - A container for multi-experiment data
 #'
 #' The \code{ExperimentList} class is a container that builds on
 #' the \code{SimpleList} with additional
@@ -32,20 +36,20 @@
 #' \strong{mergeReplicates} method, additional arguments are passed to the
 #' given \code{simplify} function argument (e.g., na.rm = TRUE)
 #'
+#' @return An \code{ExperimentList} class object
+#'
 #' @examples
+#'
 #' ExperimentList()
 #'
 #' @exportClass ExperimentList
-#' @name ExperimentList-class
-#' @docType class
 setClass("ExperimentList", contains = "SimpleList")
 
 ### - - - - - - - - - - - - - - - - - - - - - - - -
 ### Constructor
 ###
 
-#' Construct an \code{ExperimentList} object for the \code{MultiAssayExperiment}
-#' object slot.
+#' Represent multiple experiments as a List-derivative \code{ExperimentList}
 #'
 #' The \code{ExperimentList} class can contain several different types of data.
 #' The only requirements for an \code{ExperimentList} class are that the
@@ -173,7 +177,7 @@ coerceToExperimentList <- function(from) {
 }
 
 #' @rdname ExperimentList-class
-#' @name coerce
+#' @name coerce-ExperimentList
 #'
 #' @aliases coerce,list,ExperimentList-method coerce,List,ExperimentList-method
 #'
@@ -202,8 +206,7 @@ setAs("List", "ExperimentList", function(from) {
 #' @describeIn ExperimentList check for zero length across all
 #' experiments
 setMethod("isEmpty", "ExperimentList", function(x) {
-    x <- Filter(function(y) {
-        !(is.matrix(y) && identical(dim(y), c(1L, 1L)) && isTRUE(is.na(y)))
-    }, x)
-    callNextMethod()
+    all(
+        vapply(x, .isEmpty, logical(1L))
+    )
 })
