@@ -12,8 +12,21 @@ test_that("ExperimentList constructors work", {
     expect_true(validObject(ExperimentList(list(m=m))))
 })
 
+test_that("ExperimentList constructor preserves metadata", {
+    mcoldf <- DataFrame(AssayNumber=seq_len(length(ExpList)),
+        row.names = names(ExpList))
+    mcols(ExpList) <- mcoldf
+
+    metalist <- list(Shiny = "Blue Jeans", Old = "Metadata")
+    metadata(ExpList) <- metalist
+
+    nexp <- ExperimentList(ExpList)
+
+    expect_identical(mcols(nexp), mcoldf)
+    expect_identical(metadata(nexp), metalist)
+})
+
 test_that("Metadata is kept in ExperimentList when replacing", {
-    example("MultiAssayExperiment")
     ## add metadata columns and metadata
     mcoldf <- DataFrame(AssayNumber=seq_len(length(ExpList)),
         row.names = names(ExpList))
@@ -22,8 +35,9 @@ test_that("Metadata is kept in ExperimentList when replacing", {
     metalist <- list(Shiny = "Blue Jeans", Old = "Metadata")
     metadata(ExpList) <- metalist
 
-    experiments(mae) <- ExpList
+    mae0 <- mae
+    experiments(mae0) <- ExpList
 
-    expect_identical(mcols(experiments(mae)), mcoldf)
-    expect_identical(metadata(experiments(mae)), metalist)
+    expect_identical(mcols(experiments(mae0)), mcoldf)
+    expect_identical(metadata(experiments(mae0)), metalist)
 })
